==> hom.Ce.inp.db_2.3.2.tar.gz: hom.Ce.inp.db/man/hom.Ce.inpORGVSORGMAP.Rd <==
\name{hom.Ce.inpHOMSA}
\alias{hom.Ce.inpAEDAE}
\alias{hom.Ce.inpANOGA}
\alias{hom.Ce.inpAPIME}
\alias{hom.Ce.inpARATH}
\alias{hom.Ce.inpBOSTA}
\alias{hom.Ce.inpCAEBR}
\alias{hom.Ce.inpCAEEL}
\alias{hom.Ce.inpCAERE}
\alias{hom.Ce.inpCANFA}
\alias{hom.Ce.inpCANGL}
\alias{hom.Ce.inpCIOIN}
\alias{hom.Ce.inpCRYNE}
\alias{hom.Ce.inpDANRE}
\alias{hom.Ce.inpDEBHA}
\alias{hom.Ce.inpDICDI}
\alias{hom.Ce.inpDROME}
\alias{hom.Ce.inpDROPS}
\alias{hom.Ce.inpENTHI}
\alias{hom.Ce.inpESCCO}
\alias{hom.Ce.inpFUGRU}
\alias{hom.Ce.inpGALGA}
\alias{hom.Ce.inpGASAC}
\alias{hom.Ce.inpHOMSA}
\alias{hom.Ce.inpKLULA}
\alias{hom.Ce.inpMACMU}
\alias{hom.Ce.inpMONDO}
\alias{hom.Ce.inpMUSMU}
\alias{hom.Ce.inpORYSA}
\alias{hom.Ce.inpPANTR}
\alias{hom.Ce.inpRATNO}
\alias{hom.Ce.inpSACCE}
\alias{hom.Ce.inpSCHPO}
\alias{hom.Ce.inpTETNI}
\alias{hom.Ce.inpXENTR}
\alias{hom.Ce.inpYARLI}
\title{Map between IDs for genes in one organism to their predicted
  paralogs in another}
\description{ 
  A map of this type is an R object that provides mappings between
  identifiers for genes in the package organism and their predicted
  paralogs in the map that the organism is named after.  So for example,
  if the inparanoid package is the human package, then the
  hom.Ce.inpRATNO map would provide mappings between human and rat.
}
\details{
    Mappings between gene identifiers and their paralogs as predicted by
    the Inparanoid algorithm.  The map filters out paralogs that have an
    Inparanoid score less than 100%.

    Mappings are normally given from the ID of the organism in the
    package to the IDs of the organism listed in the map name.

    Reversal can be made of ANY map by using the function revmap (see
    examples below).

    Names for these maps are done in the "INPARANOID style" which means
    that they are normally the 1st three letters of the genus followed
    by the 1st two letters of the species.  For example: "Mus musculus"
    becomes "MUSMU", "Homo sapiens" becomes "HOMSA", "Monodelphis
    domestica" becomes "MONDO" etc. This means that for most of these
    organisms it will be possible to easily guess the abbreviations
    used.  An exception may occur in the future if a new model organism
    has a very similar genus and species name to an existing one.
}
\references{
\url{http://inparanoid.sbc.su.se/download/current/sqltables}
}
\examples{
        x <- hom.Ce.inpAPIME
        # Get honeybee IDs that are paralogous to the pkg IDs
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

        #Now for the reverse map (honeybee IDs back to pkg paralog)
        x <- revmap(hom.Ce.inpAPIME)
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five IDs
          xx[1:5]
          # Get the first one
          xx[[1]]
        }         

    \dontrun{
        #For the most common organisms, we try to ensure that you can
        #map back to an Entrez Gene ID by providing you with necessary
        #maps in the related organism based annotation packages.  The
        #following example shows how to get from an Entrez Gene ID for
        #Human to Entrez Gene IDs for Mouse even though inparanoid does
        #not map to Entrez Gene IDs for either of these species.

        #You will have to include the appropriate packages for
        #humans:
        library("org.Hs.eg.db")
        #and for mouse:
        library("org.Mm.eg.db")
        #And of course you will need the inparanoid package:
        library("hom.Hs.inp.db")

        #Start with some Human Entrez Gene IDs
        humanEGIds <- c("4488","4487")

        #Inparanoid uses ensembl protein IDs so start with
        #those. Notice that there will be many protein IDs returned for
        #a typical gene since there are many possible translations.
        humanProtIds <- mget(humanEGIds,org.Hs.egENSEMBLPROT)

        #Map the IDs that we can from inparanoid. Notice that by design,
        #inparanoid only represents each gene product with a single
        #translation product. Therefore your list could slim down a lot
        #during this step.  Also, if the thing you are trying to match
        #up at this step has less than 100\% seed status, you will not
        #find it in this step.
        rawMouseProtIds <- mget(unlist(humanProtIds),hom.Hs.inpMUSMU,ifnotfound=NA)
        #This also means that we need to clean up the NAs from our result
        mouseProtIds <- rawMouseProtIds[!is.na(rawMouseProtIds)]

        #Then use the mouse organism based packages to convert these IDs
        #back to an Entrez Gene ID again (this time for mouse). 
        mouseEGIds <- mget(unlist(mouseProtIds),org.Mm.egMGI2EG,ifnotfound=NA)

        #Now go ahead and have a look at the output
        mouseEGIds
    }

}
\keyword{datasets}

==> hom.Ce.inp.db_2.4.1.tar.gz: hom.Ce.inp.db/man/hom.Ce.inpORGVSORGMAP.Rd <==
\name{hom.Ce.inpHOMSA}
\alias{hom.Ce.inpACYPI}
\alias{hom.Ce.inpAEDAE}
\alias{hom.Ce.inpANOGA}
\alias{hom.Ce.inpAPIME}
\alias{hom.Ce.inpARATH}
\alias{hom.Ce.inpASPFU}
\alias{hom.Ce.inpBATDE}
\alias{hom.Ce.inpBOMMO}
\alias{hom.Ce.inpBOSTA}
\alias{hom.Ce.inpBRAFL}
\alias{hom.Ce.inpBRUMA}
\alias{hom.Ce.inpCAEBRE}
\alias{hom.Ce.inpCAEBR}
\alias{hom.Ce.inpCAEEL}
\alias{hom.Ce.inpCAEJA}
\alias{hom.Ce.inpCAERE}
\alias{hom.Ce.inpCANAL}
\alias{hom.Ce.inpCANGL}
\alias{hom.Ce.inpCANFA}
\alias{hom.Ce.inpCAPSP}
\alias{hom.Ce.inpCAVPO}
\alias{hom.Ce.inpCHLRE}
\alias{hom.Ce.inpCIOIN}
\alias{hom.Ce.inpCIOSA}
\alias{hom.Ce.inpCOCIM}
\alias{hom.Ce.inpCOPCI}
\alias{hom.Ce.inpCRYNE}
\alias{hom.Ce.inpCRYHO}
\alias{hom.Ce.inpCRYPA}
\alias{hom.Ce.inpCULPI}
\alias{hom.Ce.inpCYAME}
\alias{hom.Ce.inpDANRE}
\alias{hom.Ce.inpDAPPU}
\alias{hom.Ce.inpDEBHA}
\alias{hom.Ce.inpDICDI}
\alias{hom.Ce.inpDROAN}
\alias{hom.Ce.inpDROGR}
\alias{hom.Ce.inpDROME}
\alias{hom.Ce.inpDROMO}
\alias{hom.Ce.inpDROPS}
\alias{hom.Ce.inpDROVI}
\alias{hom.Ce.inpDROWI}
\alias{hom.Ce.inpENTHI}
\alias{hom.Ce.inpEQUCA}
\alias{hom.Ce.inpESCCO}
\alias{hom.Ce.inpFUSGR}
\alias{hom.Ce.inpGALGA}
\alias{hom.Ce.inpGASAC}
\alias{hom.Ce.inpGIALA}
\alias{hom.Ce.inpHELRO}
\alias{hom.Ce.inpHOMSA}
\alias{hom.Ce.inpIXOSC}
\alias{hom.Ce.inpKLULA}
\alias{hom.Ce.inpLEIMA}
\alias{hom.Ce.inpLOTGI}
\alias{hom.Ce.inpMACMU}
\alias{hom.Ce.inpMAGGR}
\alias{hom.Ce.inpMONDO}
\alias{hom.Ce.inpMONBR}
\alias{hom.Ce.inpMUSMU}
\alias{hom.Ce.inpNASVI}
\alias{hom.Ce.inpNEMVE}
\alias{hom.Ce.inpNEUCR}
\alias{hom.Ce.inpORNAN}
\alias{hom.Ce.inpORYSA}
\alias{hom.Ce.inpORYLA}
\alias{hom.Ce.inpOSTTA}
\alias{hom.Ce.inpPANTR}
\alias{hom.Ce.inpPEDPA}
\alias{hom.Ce.inpPHYPA}
\alias{hom.Ce.inpPHYRA}
\alias{hom.Ce.inpPHYSO}
\alias{hom.Ce.inpPLAFA}
\alias{hom.Ce.inpPLAVI}
\alias{hom.Ce.inpPONPY}
\alias{hom.Ce.inpPOPTR}
\alias{hom.Ce.inpPRIPA}
\alias{hom.Ce.inpPUCGR}
\alias{hom.Ce.inpRATNO}
\alias{hom.Ce.inpRHIOR}
\alias{hom.Ce.inpSACCE}
\alias{hom.Ce.inpSCHMA}
\alias{hom.Ce.inpSCHPO}
\alias{hom.Ce.inpSCLSC}
\alias{hom.Ce.inpSORBI}
\alias{hom.Ce.inpSTANO}
\alias{hom.Ce.inpSTRPU}
\alias{hom.Ce.inpTAKRU}
\alias{hom.Ce.inpTETTH}
\alias{hom.Ce.inpTETNI}
\alias{hom.Ce.inpTHAPS}
\alias{hom.Ce.inpTHEAN}
\alias{hom.Ce.inpTHEPA}
\alias{hom.Ce.inpTRICA}
\alias{hom.Ce.inpTRIVA}
\alias{hom.Ce.inpTRIAD}
\alias{hom.Ce.inpTRYCR}
\alias{hom.Ce.inpUSTMA}
\alias{hom.Ce.inpXENTR}
\alias{hom.Ce.inpYARLI}
\title{Map between IDs for genes in one organism to their predicted
  paralogs in another}
\description{ 
  A map of this type is an R object that provides mappings between
  identifiers for genes in the package organism and their predicted
  paralogs in the map that the organism is named after.  So for example,
  if the inparanoid package is the human package, then the
  hom.Ce.inpRATNO map would provide mappings between human and rat.
}
\details{
    Mappings between gene identifiers and their paralogs as predicted by
    the Inparanoid algorithm.  The map filters out paralogs that have an
    Inparanoid score less than 100%.

    Mappings are normally given from the ID of the organism in the
    package to the IDs of the organism listed in the map name.

    Reversal can be made of ANY map by using the function revmap (see
    examples below).

    Names for these maps are done in the "INPARANOID style" which means
    that they are normally the 1st three letters of the genus followed
    by the 1st two letters of the species.  For example: "Mus musculus"
    becomes "MUSMU", "Homo sapiens" becomes "HOMSA", "Monodelphis
    domestica" becomes "MONDO" etc. This means that for most of these
    organisms it will be possible to easily guess the abbreviations
    used.  An exception may occur in the future if a new model organism
    has a very similar genus and species name to an existing one.
}
\references{
\url{http://inparanoid.sbc.su.se/download/current/sqltables}
}
\examples{
        x <- hom.Ce.inpAPIME
        # Get honeybee IDs that are paralogous to the pkg IDs
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

        #Now for the reverse map (honeybee IDs back to pkg paralog)
        x <- revmap(hom.Ce.inpAPIME)
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five IDs
          xx[1:5]
          # Get the first one
          xx[[1]]
        }         

    \dontrun{
        #For the most common organisms, we try to ensure that you can
        #map back to an Entrez Gene ID by providing you with necessary
        #maps in the related organism based annotation packages.  The
        #following example shows how to get from an Entrez Gene ID for
        #Human to Entrez Gene IDs for Mouse even though inparanoid does
        #not map to Entrez Gene IDs for either of these species.

        #You will have to include the appropriate packages for
        #humans:
        library("org.Hs.eg.db")
        #and for mouse:
        library("org.Mm.eg.db")
        #And of course you will need the inparanoid package:
        library("hom.Hs.inp.db")

        #Start with some Human Entrez Gene IDs
        humanEGIds <- c("4488","4487")

        #Inparanoid uses ensembl protein IDs so start with
        #those. Notice that there will be many protein IDs returned for
        #a typical gene since there are many possible translations.
        humanProtIds <- mget(humanEGIds,org.Hs.egENSEMBLPROT)

        #Map the IDs that we can from inparanoid. Notice that by design,
        #inparanoid only represents each gene product with a single
        #translation product. Therefore your list could slim down a lot
        #during this step.  Also, if the thing you are trying to match
        #up at this step has less than 100\% seed status, you will not
        #find it in this step.
        rawMouseProtIds <- mget(unlist(humanProtIds),hom.Hs.inpMUSMU,ifnotfound=NA)
        #This also means that we need to clean up the NAs from our result
        mouseProtIds <- rawMouseProtIds[!is.na(rawMouseProtIds)]

        #Then use the mouse organism based packages to convert these IDs
        #back to an Entrez Gene ID again (this time for mouse). 
        mouseEGIds <- mget(unlist(mouseProtIds),org.Mm.egMGI2EG,ifnotfound=NA)

        #Now go ahead and have a look at the output
        mouseEGIds
    }

}
\keyword{datasets}
